**To delete event subscription**

The following ``delete-event-subscription`` example deletes the specified event notification subscription. ::

    aws redshift delete-event-subscription \
        --subscription-name mysubscription

This command does not produce any output.

For more information, see `Subscribing to Amazon Redshift Event Notifications <https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-event-notifications.html>`__ in the *Amazon Redshift Cluster Management Guide*.
